@@ -5,11 +5,11 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '2.003005';
+our $VERSION = '2.004000';
 
 use Moo;
 
-use Data::Validate::IP 0.19 qw( is_public_ipv4 is_public_ipv6 );
+use Data::Validate::IP 0.25 qw( is_public_ip );
 use GeoIP2::Error::Generic;
 use GeoIP2::Error::HTTP;
 use GeoIP2::Error::IPAddressNotFound;
@@ -128,8 +128,7 @@ my %spec = (
             'is a public IP address or me' => sub {
                 return defined $_[0]
                     && ( $_[0] eq 'me'
-                    || is_public_ipv4( $_[0] )
-                    || is_public_ipv6( $_[0] ) );
+                    || is_public_ip( $_[0] ) );
             }
         },
     },
@@ -318,7 +317,7 @@ GeoIP2::WebService::Client - Perl API for the GeoIP2 Precision web services
 
 =head1 VERSION
 
-version 2.003005
+version 2.004000
 
 =head1 SYNOPSIS
 
